@@ -7,6 +7,7 @@ use cache_key::RepositoryUrl;
 use dashmap::mapref::one::Ref;
 use dashmap::DashMap;
 use fs_err::tokio as fs;
+use reqwest_middleware::ClientWithMiddleware;
 use uv_fs::LockedFile;
 
 use crate::{Fetch, GitReference, GitSha, GitSource, GitUrl, Reporter};
@@ -26,15 +27,6 @@ pub enum GitResolverError {
 pub struct GitResolver(Arc<DashMap<RepositoryReference, GitSha>>);
 
 impl GitResolver {
-    /// Initialize a [`GitResolver`] with a set of resolved references.
-    pub fn from_refs(refs: Vec<ResolvedRepositoryReference>) -> Self {
-        Self(Arc::new(
-            refs.into_iter()
-                .map(|ResolvedRepositoryReference { reference, sha }| (reference, sha))
-                .collect(),
-        ))
-    }
-
     /// Inserts a new [`GitSha`] for the given [`RepositoryReference`].
     pub fn insert(&self, reference: RepositoryReference, sha: GitSha) {
         self.0.insert(reference, sha);
@@ -51,6 +43,7 @@ impl GitResolver {
     pub async fn fetch(
         &self,
         url: &GitUrl,
+        client: ClientWithMiddleware,
         cache: PathBuf,
         reporter: Option<impl Reporter + 'static>,
     ) -> Result<Fetch, GitResolverError> {
@@ -61,15 +54,15 @@ impl GitResolver {
         fs::create_dir_all(&lock_dir).await?;
         let repository_url = RepositoryUrl::new(url.repository());
         let _lock = LockedFile::acquire(
-            lock_dir.join(cache_key::digest(&repository_url)),
+            lock_dir.join(cache_key::cache_digest(&repository_url)),
             &repository_url,
         )?;
 
         // Fetch the Git repository.
         let source = if let Some(reporter) = reporter {
-            GitSource::new(url.clone(), cache).with_reporter(reporter)
+            GitSource::new(url.clone(), client, cache).with_reporter(reporter)
         } else {
-            GitSource::new(url.clone(), cache)
+            GitSource::new(url.clone(), client, cache)
         };
         let fetch = tokio::task::spawn_blocking(move || source.fetch())
             .await?
@@ -89,7 +82,8 @@ impl GitResolver {
     pub async fn resolve(
         &self,
         url: &GitUrl,
-        cache: impl Into<PathBuf>,
+        client: ClientWithMiddleware,
+        cache: PathBuf,
         reporter: Option<impl Reporter + 'static>,
     ) -> Result<Option<GitUrl>, GitResolverError> {
         // If the Git reference already contains a complete SHA, short-circuit.
@@ -105,16 +99,7 @@ impl GitResolver {
             }
         }
 
-        // Fetch the precise SHA of the Git reference (which could be a branch, a tag, a partial
-        // commit, etc.).
-        let source = if let Some(reporter) = reporter {
-            GitSource::new(url.clone(), cache).with_reporter(reporter)
-        } else {
-            GitSource::new(url.clone(), cache)
-        };
-        let fetch = tokio::task::spawn_blocking(move || source.fetch())
-            .await?
-            .map_err(GitResolverError::Git)?;
+        let fetch = self.fetch(url, client, cache, reporter).await?;
         let git = fetch.into_git();
 
         // Insert the resolved URL into the in-memory cache.
