@@ -1,4 +1,5 @@
 use either::Either;
+use std::borrow::Cow;
 
 use pep508_rs::MarkerEnvironment;
 use pypi_types::Requirement;
@@ -97,7 +98,7 @@ impl Manifest {
         &'a self,
         markers: Option<&'a MarkerEnvironment>,
         mode: DependencyMode,
-    ) -> impl Iterator<Item = &Requirement> + 'a {
+    ) -> impl Iterator<Item = Cow<'a, Requirement>> + 'a {
         self.requirements_no_overrides(markers, mode)
             .chain(self.overrides(markers, mode))
     }
@@ -107,7 +108,7 @@ impl Manifest {
         &'a self,
         markers: Option<&'a MarkerEnvironment>,
         mode: DependencyMode,
-    ) -> impl Iterator<Item = &Requirement> + 'a {
+    ) -> impl Iterator<Item = Cow<'a, Requirement>> + 'a {
         match mode {
             // Include all direct and transitive requirements, with constraints and overrides applied.
             DependencyMode::Transitive => Either::Left(
@@ -128,14 +129,15 @@ impl Manifest {
                     .chain(
                         self.constraints
                             .requirements()
-                            .filter(move |requirement| requirement.evaluate_markers(markers, &[])),
+                            .filter(move |requirement| requirement.evaluate_markers(markers, &[]))
+                            .map(Cow::Borrowed),
                     ),
             ),
             // Include direct requirements, with constraints and overrides applied.
             DependencyMode::Direct => Either::Right(
                 self.overrides
                     .apply(&self.requirements)
-                    .chain(self.constraints.requirements())
+                    .chain(self.constraints.requirements().map(Cow::Borrowed))
                     .filter(move |requirement| requirement.evaluate_markers(markers, &[])),
             ),
         }
@@ -146,19 +148,21 @@ impl Manifest {
         &'a self,
         markers: Option<&'a MarkerEnvironment>,
         mode: DependencyMode,
-    ) -> impl Iterator<Item = &Requirement> + 'a {
+    ) -> impl Iterator<Item = Cow<'a, Requirement>> + 'a {
         match mode {
             // Include all direct and transitive requirements, with constraints and overrides applied.
             DependencyMode::Transitive => Either::Left(
                 self.overrides
                     .requirements()
-                    .filter(move |requirement| requirement.evaluate_markers(markers, &[])),
+                    .filter(move |requirement| requirement.evaluate_markers(markers, &[]))
+                    .map(Cow::Borrowed),
             ),
             // Include direct requirements, with constraints and overrides applied.
             DependencyMode::Direct => Either::Right(
                 self.overrides
                     .requirements()
-                    .filter(move |requirement| requirement.evaluate_markers(markers, &[])),
+                    .filter(move |requirement| requirement.evaluate_markers(markers, &[]))
+                    .map(Cow::Borrowed),
             ),
         }
     }
@@ -177,7 +181,7 @@ impl Manifest {
         &'a self,
         markers: Option<&'a MarkerEnvironment>,
         mode: DependencyMode,
-    ) -> impl Iterator<Item = &PackageName> + 'a {
+    ) -> impl Iterator<Item = Cow<'a, PackageName>> + 'a {
         match mode {
             // Include direct requirements, dependencies of editables, and transitive dependencies
             // of local packages.
@@ -197,7 +201,10 @@ impl Manifest {
                             .apply(&self.requirements)
                             .filter(move |requirement| requirement.evaluate_markers(markers, &[])),
                     )
-                    .map(|requirement| &requirement.name),
+                    .map(|requirement| match requirement {
+                        Cow::Borrowed(requirement) => Cow::Borrowed(&requirement.name),
+                        Cow::Owned(requirement) => Cow::Owned(requirement.name),
+                    }),
             ),
 
             // Restrict to the direct requirements.
@@ -205,7 +212,10 @@ impl Manifest {
                 self.overrides
                     .apply(self.requirements.iter())
                     .filter(move |requirement| requirement.evaluate_markers(markers, &[]))
-                    .map(|requirement| &requirement.name),
+                    .map(|requirement| match requirement {
+                        Cow::Borrowed(requirement) => Cow::Borrowed(&requirement.name),
+                        Cow::Owned(requirement) => Cow::Owned(requirement.name),
+                    }),
             ),
         }
     }
@@ -217,7 +227,7 @@ impl Manifest {
     pub fn apply<'a>(
         &'a self,
         requirements: impl IntoIterator<Item = &'a Requirement>,
-    ) -> impl Iterator<Item = &Requirement> {
+    ) -> impl Iterator<Item = Cow<'a, Requirement>> {
         self.constraints.apply(self.overrides.apply(requirements))
     }
 
