@@ -302,6 +302,7 @@ pub(crate) struct ToolInstallSettings {
     pub(crate) refresh: Refresh,
     pub(crate) settings: ResolverInstallerSettings,
     pub(crate) force: bool,
+    pub(crate) editable: bool,
 }
 
 impl ToolInstallSettings {
@@ -310,6 +311,7 @@ impl ToolInstallSettings {
     pub(crate) fn resolve(args: ToolInstallArgs, filesystem: Option<FilesystemOptions>) -> Self {
         let ToolInstallArgs {
             package,
+            editable,
             from,
             with,
             with_requirements,
@@ -330,6 +332,7 @@ impl ToolInstallSettings {
                 .collect(),
             python,
             force,
+            editable,
             refresh: Refresh::from(refresh),
             settings: ResolverInstallerSettings::combine(
                 resolver_installer_options(installer, build),
@@ -524,6 +527,7 @@ pub(crate) struct SyncSettings {
     pub(crate) python: Option<String>,
     pub(crate) refresh: Refresh,
     pub(crate) settings: ResolverInstallerSettings,
+    pub(crate) directory: Option<PathBuf>,
 }
 
 impl SyncSettings {
@@ -543,6 +547,7 @@ impl SyncSettings {
             build,
             refresh,
             python,
+            directory,
         } = args;
 
         let modifications = if no_clean {
@@ -566,6 +571,7 @@ impl SyncSettings {
                 resolver_installer_options(installer, build),
                 filesystem,
             ),
+            directory,
         }
     }
 }
@@ -579,6 +585,7 @@ pub(crate) struct LockSettings {
     pub(crate) python: Option<String>,
     pub(crate) refresh: Refresh,
     pub(crate) settings: ResolverSettings,
+    pub(crate) directory: Option<PathBuf>,
 }
 
 impl LockSettings {
@@ -592,6 +599,7 @@ impl LockSettings {
             build,
             refresh,
             python,
+            directory,
         } = args;
 
         Self {
@@ -600,6 +608,7 @@ impl LockSettings {
             python,
             refresh: Refresh::from(refresh),
             settings: ResolverSettings::combine(resolver_options(resolver, build), filesystem),
+            directory,
         }
     }
 }
@@ -1237,8 +1246,7 @@ impl PipFreezeSettings {
 #[allow(clippy::struct_excessive_bools)]
 #[derive(Debug, Clone)]
 pub(crate) struct PipListSettings {
-    pub(crate) editable: bool,
-    pub(crate) exclude_editable: bool,
+    pub(crate) editable: Option<bool>,
     pub(crate) exclude: Vec<PackageName>,
     pub(crate) format: ListFormat,
     pub(crate) settings: PipSettings,
@@ -1261,8 +1269,7 @@ impl PipListSettings {
         } = args;
 
         Self {
-            editable,
-            exclude_editable,
+            editable: flag(editable, exclude_editable),
             exclude,
             format,
             settings: PipSettings::combine(
@@ -1400,6 +1407,7 @@ pub(crate) struct VenvSettings {
     pub(crate) name: PathBuf,
     pub(crate) prompt: Option<String>,
     pub(crate) system_site_packages: bool,
+    pub(crate) relocatable: bool,
     pub(crate) settings: PipSettings,
 }
 
@@ -1415,6 +1423,7 @@ impl VenvSettings {
             name,
             prompt,
             system_site_packages,
+            relocatable,
             index_args,
             index_strategy,
             keyring_provider,
@@ -1429,6 +1438,7 @@ impl VenvSettings {
             name,
             prompt,
             system_site_packages,
+            relocatable,
             settings: PipSettings::combine(
                 PipOptions {
                     python,
